# Inq

<div align="center">

![Logo](https://raw.githubusercontent.com/robvanderleek/inq/main/docs/assets/logo-light.png)

</div>

<div align="center">

  *CLI for user input 🎙️*

</div>

<div align="center">
